@rem
@rem Copyright 2015 the original author or authors.
@rem
@rem Licensed under the Apache License, Version 2.0 (the "License");
@rem you may not use this file except in compliance with the License.
@rem You may obtain a copy of the License at
@rem
@rem      https://www.apache.org/licenses/LICENSE-2.0
@rem
@rem Unless required by applicable law or agreed to in writing, software
@rem distributed under the License is distributed on an "AS IS" BASIS,
@rem WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@rem See the License for the specific language governing permissions and
@rem limitations under the License.
@rem

@if "%DEBUG%" == "" @echo off
@rem ##########################################################################
@rem
@rem  xl-license-generator startup script for Windows
@rem
@rem ##########################################################################

@rem Set local scope for the variables with windows NT shell
if "%OS%"=="Windows_NT" setlocal

set DIRNAME=%~dp0
if "%DIRNAME%" == "" set DIRNAME=.
set APP_BASE_NAME=%~n0
set APP_HOME=%DIRNAME%..

@rem Resolve any "." and ".." in APP_HOME to make it shorter.
for %%i in ("%APP_HOME%") do set APP_HOME=%%~fi

@rem Add default JVM options here. You can also use JAVA_OPTS and XL_LICENSE_GENERATOR_OPTS to pass JVM options to this script.
set DEFAULT_JVM_OPTS=

@rem Find java.exe
if defined JAVA_HOME goto findJavaFromJavaHome

set JAVA_EXE=java.exe
%JAVA_EXE% -version >NUL 2>&1
if "%ERRORLEVEL%" == "0" goto init

echo.
echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
echo.
echo Please set the JAVA_HOME variable in your environment to match the
echo location of your Java installation.

goto fail

:findJavaFromJavaHome
set JAVA_HOME=%JAVA_HOME:"=%
set JAVA_EXE=%JAVA_HOME%/bin/java.exe

if exist "%JAVA_EXE%" goto init

echo.
echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME%
echo.
echo Please set the JAVA_HOME variable in your environment to match the
echo location of your Java installation.

goto fail

:init
@rem Get command-line arguments, handling Windows variants

if not "%OS%" == "Windows_NT" goto win9xME_args

:win9xME_args
@rem Slurp the command line arguments.
set CMD_LINE_ARGS=
set _SKIP=2

:win9xME_args_slurp
if "x%~1" == "x" goto execute

set CMD_LINE_ARGS=%*

:execute
@rem Setup the command line

set CLASSPATH=%APP_HOME%\lib\xl-license-generator-10.2.12.jar;%APP_HOME%\lib\xl-license-10.2.12.jar;%APP_HOME%\lib\xl-license-api-10.2.12.jar;%APP_HOME%\lib\xl-repository-api-10.2.12.jar;%APP_HOME%\lib\xl-core-10.2.12.jar;%APP_HOME%\lib\args4j-2.33.jar;%APP_HOME%\lib\local-booter-10.2.12.jar;%APP_HOME%\lib\packager-10.2.12.jar;%APP_HOME%\lib\engine-spi-10.2.12.jar;%APP_HOME%\lib\xl-script-engine-10.2.12.jar;%APP_HOME%\lib\xl-utils-10.2.12.jar;%APP_HOME%\lib\xl-security-converter-10.2.12.jar;%APP_HOME%\lib\engine-xml-10.2.12.jar;%APP_HOME%\lib\xl-chain-of-custody-10.2.12.jar;%APP_HOME%\lib\engine-api-10.2.12.jar;%APP_HOME%\lib\udm-plugin-api-10.2.12.jar;%APP_HOME%\lib\aws-java-sdk-marketplacemeteringservice-1.11.883.jar;%APP_HOME%\lib\aws-java-sdk-core-1.11.883.jar;%APP_HOME%\lib\joda-time-2.10.10.jar;%APP_HOME%\lib\xl-security-core-10.2.12.jar;%APP_HOME%\lib\overthere-5.3.5.jar;%APP_HOME%\lib\scannit-1.4.1.jar;%APP_HOME%\lib\truezip-driver-zip-7.7.10.jar;%APP_HOME%\lib\sshj-0.27.0.jar;%APP_HOME%\lib\smbj-0.10.0.jar;%APP_HOME%\lib\bcpkix-jdk15on-1.68.jar;%APP_HOME%\lib\bcprov-jdk15on-1.68.jar;%APP_HOME%\lib\jakarta.servlet-api-4.0.4.jar;%APP_HOME%\lib\jmustache-1.15.jar;%APP_HOME%\lib\truezip-file-7.7.10.jar;%APP_HOME%\lib\truezip-driver-file-7.7.10.jar;%APP_HOME%\lib\truezip-driver-tar-7.7.10.jar;%APP_HOME%\lib\truezip-kernel-7.7.10.jar;%APP_HOME%\lib\t2-bus-1.2.1.jar;%APP_HOME%\lib\google-cloud-os-login-1.2.2.jar;%APP_HOME%\lib\resteasy-multipart-provider-4.6.0.Final.jar;%APP_HOME%\lib\resteasy-client-4.6.0.Final.jar;%APP_HOME%\lib\google-api-services-compute-v1-rev20210310-1.31.0.jar;%APP_HOME%\lib\google-api-client-1.31.1.jar;%APP_HOME%\lib\google-http-client-apache-v2-1.38.0.jar;%APP_HOME%\lib\google-oauth-client-1.31.2.jar;%APP_HOME%\lib\google-http-client-jackson2-1.38.0.jar;%APP_HOME%\lib\google-http-client-1.39.0.jar;%APP_HOME%\lib\httpclient-4.5.13.jar;%APP_HOME%\lib\spring-security-core-5.4.10.jar;%APP_HOME%\lib\xl-localisation-10.2.12.jar;%APP_HOME%\lib\spring-context-5.3.18.jar;%APP_HOME%\lib\spring-web-5.3.18.jar;%APP_HOME%\lib\spring-aop-5.3.18.jar;%APP_HOME%\lib\spring-beans-5.3.18.jar;%APP_HOME%\lib\asn-one-0.5.0.jar;%APP_HOME%\lib\spray-json_2.13-1.3.6.jar;%APP_HOME%\lib\xl-base-10.2.12.jar;%APP_HOME%\lib\grizzled-slf4j_2.13-1.3.4.jar;%APP_HOME%\lib\akka-slf4j_2.13-2.6.13.jar;%APP_HOME%\lib\akka-actor_2.13-2.6.13.jar;%APP_HOME%\lib\scala-xml_2.13-1.3.0.jar;%APP_HOME%\lib\scala-java8-compat_2.13-0.9.1.jar;%APP_HOME%\lib\scala-reflect-2.13.5.jar;%APP_HOME%\lib\scala-library-2.13.5.jar;%APP_HOME%\lib\dom4j-2.1.3.jar;%APP_HOME%\lib\jaxb-api-2.3.1.jar;%APP_HOME%\lib\config-1.4.1.jar;%APP_HOME%\lib\commons-compress-1.20.jar;%APP_HOME%\lib\commons-codec-1.15.jar;%APP_HOME%\lib\commons-lang-2.6.jar;%APP_HOME%\lib\jcl-over-slf4j-1.7.30.jar;%APP_HOME%\lib\slf4j-api-1.7.30.jar;%APP_HOME%\lib\jcifs-1.3.17.jar;%APP_HOME%\lib\mbassador-1.3.0.jar;%APP_HOME%\lib\commons-net-3.3.jar;%APP_HOME%\lib\jaxen-1.2.0.jar;%APP_HOME%\lib\httpcore-4.4.14.jar;%APP_HOME%\lib\jsch-0.1.55.jar;%APP_HOME%\lib\jzlib-1.1.3.jar;%APP_HOME%\lib\truezip-swing-7.7.10.jar;%APP_HOME%\lib\annotations-3.0.1.jar;%APP_HOME%\lib\javassist-3.27.0-GA.jar;%APP_HOME%\lib\opencensus-contrib-http-util-0.28.0.jar;%APP_HOME%\lib\guava-30.1.1-jre.jar;%APP_HOME%\lib\spring-expression-5.3.18.jar;%APP_HOME%\lib\spring-core-5.3.18.jar;%APP_HOME%\lib\java-semver-0.9.0.jar;%APP_HOME%\lib\jmespath-java-1.11.883.jar;%APP_HOME%\lib\jakarta.activation-api-1.2.2.jar;%APP_HOME%\lib\xstream-1.4.18.jar;%APP_HOME%\lib\jettison-1.4.1.jar;%APP_HOME%\lib\jdom-2.0.2.jar;%APP_HOME%\lib\xz-1.5.jar;%APP_HOME%\lib\eddsa-0.2.0.jar;%APP_HOME%\lib\grpc-api-1.36.0.jar;%APP_HOME%\lib\opencensus-api-0.28.0.jar;%APP_HOME%\lib\grpc-context-1.36.0.jar;%APP_HOME%\lib\proto-google-cloud-os-login-v1-1.2.2.jar;%APP_HOME%\lib\jsr305-3.0.2.jar;%APP_HOME%\lib\animal-sniffer-annotations-1.20.jar;%APP_HOME%\lib\grpc-stub-1.36.0.jar;%APP_HOME%\lib\error_prone_annotations-2.5.1.jar;%APP_HOME%\lib\grpc-protobuf-1.36.0.jar;%APP_HOME%\lib\grpc-protobuf-lite-1.36.0.jar;%APP_HOME%\lib\api-common-1.10.1.jar;%APP_HOME%\lib\auto-value-annotations-1.7.4.jar;%APP_HOME%\lib\protobuf-java-3.15.5.jar;%APP_HOME%\lib\proto-google-common-protos-2.1.0.jar;%APP_HOME%\lib\failureaccess-1.0.1.jar;%APP_HOME%\lib\listenablefuture-9999.0-empty-to-avoid-conflict-with-guava.jar;%APP_HOME%\lib\checker-compat-qual-2.5.5.jar;%APP_HOME%\lib\j2objc-annotations-1.3.jar;%APP_HOME%\lib\gax-1.62.0.jar;%APP_HOME%\lib\gax-grpc-1.62.0.jar;%APP_HOME%\lib\grpc-auth-1.36.0.jar;%APP_HOME%\lib\google-auth-library-credentials-0.24.1.jar;%APP_HOME%\lib\grpc-netty-shaded-1.36.0.jar;%APP_HOME%\lib\grpc-core-1.36.0.jar;%APP_HOME%\lib\annotations-4.1.1.4.jar;%APP_HOME%\lib\perfmark-api-0.23.0.jar;%APP_HOME%\lib\grpc-alts-1.36.0.jar;%APP_HOME%\lib\grpc-grpclb-1.36.0.jar;%APP_HOME%\lib\conscrypt-openjdk-uber-2.5.1.jar;%APP_HOME%\lib\threetenbp-1.5.0.jar;%APP_HOME%\lib\google-cloud-core-1.94.3.jar;%APP_HOME%\lib\protobuf-java-util-3.15.5.jar;%APP_HOME%\lib\proto-google-iam-v1-1.0.10.jar;%APP_HOME%\lib\google-http-client-gson-1.39.0.jar;%APP_HOME%\lib\gson-2.8.6.jar;%APP_HOME%\lib\google-auth-library-oauth2-http-0.24.1.jar;%APP_HOME%\lib\jcip-annotations-1.0.jar;%APP_HOME%\lib\checker-qual-3.8.0.jar;%APP_HOME%\lib\spring-jcl-5.3.18.jar;%APP_HOME%\lib\jython-standalone-2.7.2-xebialabs-1.jar;%APP_HOME%\lib\ion-java-1.0.2.jar;%APP_HOME%\lib\jackson-annotations-2.12.3.jar;%APP_HOME%\lib\jackson-dataformat-cbor-2.12.3.jar;%APP_HOME%\lib\jackson-core-2.12.3.jar;%APP_HOME%\lib\jackson-databind-2.12.3.jar;%APP_HOME%\lib\joda-convert-2.2.1.jar;%APP_HOME%\lib\mxparser-1.2.2.jar;%APP_HOME%\lib\resteasy-client-api-4.6.0.Final.jar;%APP_HOME%\lib\resteasy-core-4.6.0.Final.jar;%APP_HOME%\lib\resteasy-core-spi-4.6.0.Final.jar;%APP_HOME%\lib\resteasy-jaxb-provider-4.6.0.Final.jar;%APP_HOME%\lib\smallrye-config-1.6.2.jar;%APP_HOME%\lib\smallrye-config-common-1.6.2.jar;%APP_HOME%\lib\jboss-logging-3.4.1.Final.jar;%APP_HOME%\lib\apache-mime4j-storage-0.8.3.jar;%APP_HOME%\lib\commons-io-2.8.0.jar;%APP_HOME%\lib\jboss-jaxrs-api_2.1_spec-2.0.1.Final.jar;%APP_HOME%\lib\jakarta.mail-1.6.7.jar;%APP_HOME%\lib\apache-mime4j-dom-0.8.3.jar;%APP_HOME%\lib\microprofile-config-api-2.0.jar;%APP_HOME%\lib\xmlpull-1.1.3.1.jar;%APP_HOME%\lib\reactive-streams-1.0.3.jar;%APP_HOME%\lib\jakarta.validation-api-2.0.2.jar;%APP_HOME%\lib\jboss-annotations-api_1.3_spec-2.0.1.Final.jar;%APP_HOME%\lib\jaxb-runtime-2.3.4.jar;%APP_HOME%\lib\jakarta.activation-1.2.2.jar;%APP_HOME%\lib\asyncutil-0.1.0.jar;%APP_HOME%\lib\apache-mime4j-core-0.8.3.jar;%APP_HOME%\lib\txw2-2.3.4.jar;%APP_HOME%\lib\istack-commons-runtime-3.0.12.jar


@rem Execute xl-license-generator
"%JAVA_EXE%" %DEFAULT_JVM_OPTS% %JAVA_OPTS% %XL_LICENSE_GENERATOR_OPTS%  -classpath "%CLASSPATH%" com.xebialabs.license.generator.LicenseGenerator %CMD_LINE_ARGS%

:end
@rem End local scope for the variables with windows NT shell
if "%ERRORLEVEL%"=="0" goto mainEnd

:fail
rem Set variable XL_LICENSE_GENERATOR_EXIT_CONSOLE if you need the _script_ return code instead of
rem the _cmd.exe /c_ return code!
if  not "" == "%XL_LICENSE_GENERATOR_EXIT_CONSOLE%" exit 1
exit /b 1

:mainEnd
if "%OS%"=="Windows_NT" endlocal

:omega
